import pyttsx3
import speech_recognition as sr
from gtts import gTTS
import playsound

def speakGTTs(text, lang_='en', **kwargs):
        text = text
        tts = gTTS(text, lang=lang_)
        filename = 'voice.mp3'
        tts.save(filename)
        print(kwargs['value'] + text)
        playsound.playsound(filename)
    


class initPyttsx3:
    def __init__(self, name, voiceId: int = 1):
        self.ai = pyttsx3.init()
        self.voice = self.ai.getProperty('voices')
        self.ai.setProperty(name, self.voice[voiceId].id)
    def speak(self, audio, **kwargs):
        print(kwargs['value'] + audio)
        self.ai.say(audio)
        self.ai.runAndWait()
        return audio

class command:
    @staticmethod
    def init(lang='en'):
        c = sr.Recognizer()
        with sr.Microphone() as source:
            c.pause_threshold = 1
            audio = c.listen(source)
            try:
                query = c.recognize_google(audio, language=lang)
                print(f"Khoa: {query}")
            except sr.UnknownValueError:
                print('Error Code: UnknownValueError')
                query = str(input("Your order is: "))
            return query




from Easy_AI import *

def brain():
    while True:
        try:
            query = command.init().lower
            if 'hello' in query:
                speakGTTs('Hello', value="AI: ")
        except KeyboardInterrupt:
            speakGTTs('AI is quiting', value="AI: ")
            break

brain()



from setuptools import setup

def readme():
    with open('README.md') as f:
        f.read()

setup(
   name='Easy_AI',
   version='0.0.2',
   description='My Project Dont Touch',
   long_description = readme(),
   long_description_content_type='text/markdown',
   author='Khoa1468',
   author_email='khoalam1468@gmail.com',
   packages=['Easy_AI'],  #same as name
   install_requires=[
       'pyttsx3',
       'SpeechRecognition',
       'gtts',
       'playsound'
   ], #external packages as dependencies
)